"""This is main graspfile module for manipulating files from TICRA Tools, GRASP and CHAMP

Submodules
==========

.. autosummary::
    :toctree: _autosummary

    cut
    grid
    torfile
    torparser
    analysis
    plot
"""

__version__ = '0.4.0'

__all__ = ['cut', 'grid', 'plot', 'torfile', 'torparser', 'analysis']
